# mebularts

TR | @mebularts tarafından ♥ ile kodlanmıştır. Sahte Türk isim, soyisim, kullanıcı adı, adres, telefon numarası, doğum tarihi, şirket adı, email ve user_agent üretmek için ücretsiz bir kütüphane.

EN | Coded with ♥ by @mebularts. A free library to generate fake Turkish names, surnames, usernames, addresses, phone numbers, dates of birth, company names, emails and user_agents.

## Kurulum / Install

```sh
pip install mebularts
```

## Kullanım / Usage

```python
import mebularts

print(mebularts.fake_male_first_name())
print(mebularts.fake_female_first_name())
print(mebularts.fake_last_name())
print(mebularts.fake_username())
print(mebularts.fake_email())
print(mebularts.fake_phone_number())
print(mebularts.fake_address())
print(mebularts.fake_birthdate())
print(mebularts.fake_company_name())
print(mebularts.fake_user_agent())
```
```
